Coverage for modules/box__bizhelp/contact/templates/contact/blocks/sidebar.html: 100%

# Coverage for modules/box__bizhelp/contact/templates/contact/blocks/sidebar.html : 100%

## 2 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1{{

2 sidebar_item('Home',

3 icon='fa fa-envelope',

4 url=url_for('contact.dashboard')

5)

6}}

7

8{{

9 sidebar_item('Contact Page',

10 icon='fa fa-globe',

11 url=url_for('contact.index')

12)

13}}